# pyqtapplicationhelper

## Distributing

Check any of the Release/* branches to find the needed version
Check under dist for the .whl file

```bash
pip install *.whl
```

## Making Wheel

```bash
python setup.py bdist_wheel --universal
```
